-- Class: ColourCanvas
-- SDK: Corona - 09/12/11
-- Author: Andrew Burch
-- Date: 28/01/12
-- Site: http://www.newhighscore.net
-- Contact: andrew.burch@newhighscore.net
-- Note: Masking and alpha sample

local ColourCanvas = {}
local ColourCanvas_mt = {__index = ColourCanvas}

function ColourCanvas.new(params)
	local displayGroup = display.newGroup()
	local maxPoints = params.maxPoints
	local pointList = {}
	
	local maskImageName = params.maskImageName
	local mask = graphics.newMask(maskImageName)
	
	-- create images and masks at startup
	for i = 1, maxPoints do
		local point = display.newCircle(displayGroup, 0, 0, 32)
		point.isVisible = false
		point:setMask(mask)
		
		table.insert(pointList, {
				point = point,
				layer = 0,
			})
	end
	
	local canvas = {
		maxPoints = maxPoints,
		displayGroup = displayGroup,
		pointList = pointList,
		layerCount = params.layerCount,
		layerSpeeds = params.layerSpeeds,
		activeIndex = 0,
	}
	
	return setmetatable(canvas, ColourCanvas_mt)
end

function ColourCanvas:addNewPoint(params)
	local pointList = self.pointList
	local maxPoints = self.maxPoints
	local activeIndex = self.activeIndex
	
	local limitReached = activeIndex == maxPoints

	activeIndex = limitReached and 1 or activeIndex + 1

	local layerCount = self.layerCount
	local pointInfo = pointList[activeIndex]
	local point = pointInfo.point
	local colour = params.colour
	point.x = params.x
	point.y = params.y
	point.isVisible = true
	point:setFillColor(colour.r, colour.g, colour.b, colour.a)
	pointInfo.layer = params.layer
	
	self.activeIndex = activeIndex
end

function ColourCanvas:update(dt, time)
	local s1 = self.s1 or 0
	local s2 = self.s2 or 0
	local s3 = self.s3 or 0
	local radS1 = math.rad(s1)
	local radS2 = math.rad(s2)
	local radS3 = math.rad(s3)
	local sinS1 = math.sin(radS1)
	local cosS2 = math.cos(radS2)
	local sinS3 = math.sin(radS3)
	local cosS3 = math.cos(radS3)
	
	local movementX = (sinS1 * 0.5) + (cosS3 * 0.2)
	local movementY = (cosS2 * 0.2)
	
	local pointList = self.pointList
	local activeIndex = self.activeIndex
	local layerSpeeds = self.layerSpeeds
	local speed = self.speed

	for i=1, activeIndex do
		local pointInfo = pointList[i]
		local layer = pointInfo.layer
		local speedInfo = layerSpeeds[layer]
		local point = pointInfo.point
		point.x = point.x + (movementX * speedInfo.x)
		point.y = point.y + (movementY * speedInfo.y)
	end
	
	self.s1 = s1 + 0.3	
	self.s2 = s2 + 0.6
	self.s3 = s3 + 0.4
end

return ColourCanvas