-- Project: Colour Canvas Demo
-- SDK: Corona - 09/12/11
-- Author: Andrew Burch
-- Date: 28/01/12
-- Site: http://www.newhighscore.net
-- Contact: andrew.burch@newhighscore.net
-- Note: Masking and alpha sample

local colourcanvas = require('colourcanvas')

-- hide the status bar
display.setStatusBar(display.HiddenStatusBar)

local contentWidth = display.contentWidth
local contentHeight = display.contentHeight

-- setup a black background
local background = display.newRect(0, 0, contentWidth, contentHeight)
background:setFillColor(0,0,0)

-- set up the canvas system
local layerCount = 5
local canvasSystem = colourcanvas.new({
							maxPoints = 100,
							maskImageName = 'spottransition.png',
							layerCount = layerCount,
							layerSpeeds = {
								{
									x = -1.5,
									y = -0.9,
								},
								{
									x = 1.3,
									y = -0.7,
								},
								{
									x = -2.1,
									y = 1.0,
								},
								{
									x = 1.1,
									y = -0.6,
								},
								{
									x = -0.1,
									y = 0.4,
								},
							},
						})

local lastUpdateTime = 0

-- add new point to canvas
Runtime:addEventListener('touch', function(event)
										local phase = event.phase
										if phase ~= 'began' then
											return 
										end
										
										local colour = {
											r = math.random(255),
											g = math.random(255),
											b = math.random(255),
											a = 100,
										}
										local layer = math.random(1, layerCount)
										
										canvasSystem:addNewPoint({
														x = event.x,
														y = event.y,
														layer = layer,
														colour = colour,
													})

									end)

-- register main update listener
Runtime:addEventListener('enterFrame', function(event)
											local time = event.time
											local dt = (time - lastUpdateTime) / 1000
											
											canvasSystem:update(dt, time)
											
											lastUpdateTime = time
										end)